@@ -3,7 +3,7 @@
 #
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2009 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2010 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -357,7 +357,7 @@ def handle_debian_release(package, bts, ui, fromaddr, online=True, http_proxy=No
         prompt  = 'Please enter the name of the package: '
         package = ui.get_string(prompt)
         if not package:
-            ui.log_message('You seem to want to report a generic bug, not request a removal\n')
+            ui.log_message('You seem to want to report a generic bug.\n')
             return
 
         ui.log_message('Checking status database...\n')
@@ -413,8 +413,8 @@ def handle_debian_release(package, bts, ui, fromaddr, online=True, http_proxy=No
 
     if tag == 'binnmu':
         reason  = ui.get_string("binNMU changelog entry: ")
-        subject = "nmu: %s/%s" % (package, version)
-        body    = "nmu %s/%s . %s . -m \"%s\"\n" % (package, version, archs, reason)
+        subject = "nmu: %s_%s" % (package, version)
+        body    = "nmu %s_%s . %s . -m \"%s\"\n" % (package, version, archs or "ALL", reason)
     elif tag == 'transition':
         subject = 'transition: %s' % (package)
         body    = '(please explain about the transition: impacted packages, reason, ...)\n'
