@@ -1,7 +1,7 @@
 # reportbug_submit module - email and GnuPG functions
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2006 Chris Lawrence
-#   Copyright (C) 2008-2009 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2010 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -430,15 +430,11 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
             ewrite('Original write failed, wrote bug report to %s\n', msgname)
 
     if mua:
-        for bit in mua.split():
-            if '%s' not in bit: break
-        ewrite("Spawning %s...\n", bit or mua)
-        if '%s' not in mua:
-            mua += ' %s'
+        ewrite("Spawning %s...\n", mua.name)
         returnvalue = 0
         succeeded = False
         while not succeeded:
-            returnvalue = ui.system(mua % commands.mkarg(filename)[1:])
+            returnvalue = mua.send(filename)
             if returnvalue != 0:
                 ewrite("Mutt users should be aware it is mandatory to edit the draft before sending.\n")
                 mtitle = 'Report has not been sent yet; what do you want to do now?'
@@ -469,13 +465,13 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
 
         if len(addresses):
             ewrite("Copies sent to:\n")
-            for address in addresses:
-                ewrite('  %s\n', rfc822.dump_address_pair(address))
+            for address in addrs:
+                ewrite('  %s\n', address)
 
         if debbugs_cc and rtype == 'debbugs':
             ewrite("Copies will be sent after processing to:\n")
-            for address in debbugs_cc:
-                ewrite('  %s\n', rfc822.dump_address_pair(address))
+            for address in cclist:
+                ewrite('  %s\n', address)
 
     if not (exinfo or kudos) and rtype == 'debbugs' and sysinfo and not failed:
         ewrite('\n')
