@@ -81,14 +81,14 @@ def create_scrollable (widget):
 def info_dialog (message):
     dialog = gtk.MessageDialog (assistant, gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                                 gtk.MESSAGE_INFO, gtk.BUTTONS_CLOSE, message)
-    dialog.connect ('response', lambda *args: dialog.destroy ())
+    dialog.connect ('response', lambda d, *args: d.destroy ())
     dialog.set_title ('Reportbug')
     dialog.show_all ()
 
 def error_dialog (message):
     dialog = gtk.MessageDialog (assistant, gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                                 gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE, message)
-    dialog.connect ('response', lambda *args: dialog.destroy ())
+    dialog.connect ('response', lambda d, *args: d.destroy ())
     dialog.set_title ('Reportbug')
     dialog.show_all ()
 
@@ -1098,7 +1098,7 @@ class EditorPage (Page):
 
         if not has_spell:
             box = gtk.EventBox ()
-            label = gtk.Label ("Please install <b>python-gnome2-extras</b> to enable spell checking")
+            label = gtk.Label ("Please install <b>python-gtkspell</b> to enable spell checking")
             label.set_use_markup (True)
             label.set_line_wrap (True)
             box.add (label)
@@ -1268,8 +1268,10 @@ class ProgressPage (Page):
 class ReportbugAssistant (gtk.Assistant):
     def __init__ (self, application):
         gtk.Assistant.__init__ (self)
-        self.set_title ('Reportbug')
         self.application = application
+
+        self.set_title ('Reportbug')
+        self.nuke_back_button ()
         self.showing_page = None
         self.requested_page = None
         self.progress_page = None
@@ -1278,12 +1280,29 @@ class ReportbugAssistant (gtk.Assistant):
         self.connect_signals ()
         self.setup_pages ()
 
+    def nuke_back_cb (self, widget):
+        # This is a real hack for two reasons:
+        # 1. There's no other way to access action area but inspecting the assistant and searching for the back button
+        # 2. Hide back button on show, because it can be shown-hidden by the assistant depending on the page
+        if isinstance (widget, gtk.Button):
+            if widget.get_label() == 'gtk-go-back':
+                widget.connect ('show', self.on_back_show)
+                return
+        if isinstance (widget, gtk.Container):
+            widget.forall (self.nuke_back_cb)
+
+    def nuke_back_button (self):
+        self.nuke_back_cb (self)
+
     def connect_signals (self):
         self.connect ('cancel', self.close)
         self.connect ('prepare', self.on_prepare)
         self.connect ('delete-event', self.close)
         self.connect ('apply', self.close)
-        
+
+    def on_back_show (self, widget):
+        widget.hide ()
+
     def on_prepare (self, assistant, widget):
         # If the user goes back then forward, we must ensure the feedback value to reportbug must be sent
         # when the user clicks on "Forward" to the requested page by reportbug
@@ -1438,8 +1457,8 @@ def initialize ():
     try:
         vte = __import__ ("vte")
     except ImportError:
-        message = """Please install the %s package to use the gtk2 interface. 
-Falling back to text interface."""
+        message = """Please install the %s package to use the GTK+ (known as 'gtk2' in reportbug) interface.
+Falling back to 'text' interface."""
         dialog = gtk.MessageDialog (None, gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
                                     gtk.MESSAGE_INFO, gtk.BUTTONS_CLOSE, None)
         dialog.set_markup (message % "<b>python-vte</b>")
@@ -1447,6 +1466,8 @@ Falling back to text interface."""
         dialog.destroy ()
         while gtk.events_pending ():
             gtk.main_iteration ()
+        if not sys.stdout.isatty ():
+            os.execlp ('x-terminal-emulator', 'x-terminal-emulator', '-e', 'reportbug -u text')
         return False
 
     # Exception hook
@@ -1467,6 +1488,9 @@ Falling back to text interface."""
     application.start ()
     return True
 
+def can_input ():
+    return True
+
 def test ():
     # Write some tests here
     print get_password ("test")
