@@ -1,7 +1,7 @@
 # Text user interface for reportbug
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 2001-08 Chris Lawrence
-#   Copyright (C) 2008-2009 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2010 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -193,7 +193,7 @@ def select_options(msg, ok, help, allow_numbers=None, nowrap=False):
             desc += help.get(ch, help.get(ch.lower(),
                                           'No help for this option.'))
             ewrite(indent_wrap_text(desc+'\n', '%s - '% ch, 4))
-        return select_options(msg, ok, help, allow_numbers)
+        return select_options(msg, ok, help, allow_numbers, nowrap)
     elif (ch.lower() in ok) or (ch.upper() in ok):
         return ch.lower()
     elif err_message:
@@ -403,12 +403,25 @@ def show_report(number, system, mirrors,
 
     if not info:
         ewrite('No report available: #%s\n', number)
-        return
+        raise NoBugs
+
+    # extract the package name, either it's reported against
+    # the binary package or the source one
+    foundpackage = info[1][0].lower()
+    try:
+        foundpackage = foundpackage.split('package: ')[1].split('\n')[0]
+    except IndexError:
+        try:
+            foundpackage = foundpackage.split('source: ')[1].split('\n')[0]
+        except:
+            ewrite('Cannot retrieve bug\'s package, exiting...\n')
+            sys.exit(-1)
 
     (title, messages) = info
     # save report subject in main
     m = sys.modules['__main__']
     m.reporttitle = ' '.join(title.split()[2:])
+    m.foundpackage = foundpackage
 
     current_message = 0
     skip_pager = False
@@ -1014,3 +1027,6 @@ def spawn_editor(message, filename, editor, charset='utf-8'):
 
 def initialize ():
     return True
+
+def can_input():
+    return sys.stdin.isatty()
