@@ -1,7 +1,7 @@
 # urwid user interface for reportbug
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 2006-08 Chris Lawrence
-#   Copyright (C) 2008-2009 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2010 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -216,8 +216,8 @@ class displaybox(dialog):
 
 class textentry(dialog):
     def __init__(self, text, width=None, height=None, multiline=False,
-                 title=''):
-        self.edit = urwid.Edit(multiline=multiline)
+                 title='', edit_text=''):
+        self.edit = urwid.Edit(edit_text=edit_text, multiline=multiline)
         body = urwid.ListBox([self.edit])
         body = urwid.AttrWrap(body, 'selectable', 'focustext')
         if not multiline:
@@ -356,7 +356,7 @@ def get_string(prompt, options=None, title=None, empty_ok=False, force_prompt=Fa
     else:
         title = VERSION
 
-    box = textentry(prompt, title=title)
+    box = textentry(prompt, title=title, edit_text=default)
     box.add_buttons([ ("OK", 0) ])
     code, text = box.main(ui)
     return text or default
@@ -532,7 +532,7 @@ def show_report(number, system, mirrors,
 
 def handle_bts_query(package, bts, mirrors=None, http_proxy="",
                      queryonly=False, screen=None, title="", archived='no',
-                     source=False, version=None):
+                     source=False, version=None, mbox=False, buglist=None):
     from reportbug import debianbts
 
     sysinfo = debianbts.SYSTEMS[bts]
@@ -599,13 +599,13 @@ def handle_bts_query(package, bts, mirrors=None, http_proxy="",
                 cancellabel = 'Exit'
                 quitlabel = None
             else:
-                cancellabel = 'Continue'
+                cancellabel = 'New bug'
                 quitlabel='Quit'
 
             while True:
-                info = menu('Select a bug to read the report:', buglist,
+                info = menu('Select a bug to read (and possibly report more information) or report a new bug:', buglist,
                             '', ui=ui, title=sectitle, default=p,
-                            oklabel='Get info',
+                            oklabel='Read bug',
                             cancellabel=cancellabel,
                             quitlabel=quitlabel)
                 ui = None
@@ -651,6 +651,9 @@ palette = [
 def initialize ():
     return True
 
+def can_input():
+    return sys.stdin.isatty()
+
 def test():
     import time
 
