@@ -2,7 +2,7 @@
 # utils module - common functions for reportbug UIs
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2009 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2010 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -46,13 +46,16 @@ import subprocess
 import debianbts
 from string import ascii_letters, digits
 
+# needed for MUA send
+import ui.text_ui as ui
+
 # Paths for dpkg
 DPKGLIB = '/var/lib/dpkg'
 AVAILDB = os.path.join(DPKGLIB, 'available')
 STATUSDB = os.path.join(DPKGLIB, 'status')
 
 # Headers other than these become email headers for debbugs servers
-PSEUDOHEADERS = ('Package', 'Version', 'Severity', 'File', 'Tags',
+PSEUDOHEADERS = ('Package', 'Source', 'Version', 'Severity', 'File', 'Tags',
                  'Justification', 'Followup-For', 'Owner', 'User', 'Usertags')
 
 from reportbug.ui import AVAILABLE_UIS
@@ -752,13 +755,46 @@ CONFIG_ARGS = (
     'printonly', 'offline', 'check_uid', 'smtptls', 'smtpuser', 'smtppasswd',
     'paranoid')
 
+class Mua:
+    command = ""
+    name = ""
+
+    def __init__(self, command):
+        self.command = command
+        self.name = command.split()[0]
+
+    def send(self, filename):
+        mua = self.command
+        if '%s' not in mua:
+            mua += ' %s'
+        return ui.system(mua % commands.mkarg(filename)[1:])
+
+    def get_name(self):
+        return self.name
+
+class Gnus(Mua):
+    name = "gnus"
+
+    def __init__(self):
+        pass
+
+    def send(self, filename):
+        elisp = """(progn
+                      (load-file "/usr/share/reportbug/reportbug.el")
+                      (tfheen-reportbug-insert-template "%s"))"""
+        filename = re.sub("[\"\\\\]", "\\\\\\g<0>", filename)
+        elisp = commands.mkarg(elisp % filename)
+        return ui.system("emacsclient --no-wait --eval %s 2>/dev/null"
+                         " || emacs --eval %s" % (elisp, elisp))
+
 MUA = {
-    'mutt' : 'mutt -H',
-    'mh' : '/usr/bin/mh/comp -use -file',
-    'gnus' : 'REPORTBUG=%s emacs -l /usr/share/reportbug/reportbug.el -f tfheen-reportbug-insert-template',
+    'mutt' : Mua('mutt -H'),
+    'mh' : Mua('/usr/bin/mh/comp -use -file'),
+    'gnus' : Gnus(),
     }
 MUA['nmh'] = MUA['mh']
 
+# TODO: convert them to class methods
 MUAVERSION = {
     MUA['mutt'] : 'mutt -v',
     MUA['mh'] : '/usr/bin/mh/comp -use -file',
@@ -768,14 +804,16 @@ MUAVERSION = {
 def mua_is_supported(mua):
     # check if the mua is supported by reportbug
     if mua == 'mh' or mua == MUA['mh']:
-        mua = 'mh'
+        mua_tmp = 'mh'
     elif mua == 'nmh' or mua == MUA['nmh']:
-        mua = 'mh'
+        mua_tmp = 'mh'
     elif mua == 'gnus' or mua == MUA['gnus']:
-        mua = 'gnus'
+        mua_tmp = 'gnus'
+    elif mua == 'mutt' or mua == MUA['mutt']:
+        mua_tmp = 'mutt'
     else:
-        mua = mua.split()[0]
-    if mua not in MUA:
+        mua_tmp = mua
+    if mua_tmp not in MUA:
         return False
     else:
         return True
@@ -783,21 +821,23 @@ def mua_is_supported(mua):
 def mua_exists(mua):
     # check if the mua is available on the system
     if mua == 'mh' or mua == MUA['mh']:
-        mua = MUA['mh']
+        mua_tmp = MUA['mh']
     elif mua == 'nmh' or mua == MUA['nmh']:
-        mua = MUA['mh']
+        mua_tmp = MUA['mh']
     elif mua == 'gnus' or mua == MUA['gnus']:
-        mua = MUA['gnus']
+        mua_tmp = MUA['gnus']
+    elif mua == 'mutt' or mua == MUA['mutt']:
+        mua_tmp = MUA['mutt']
     else:
-        mua = MUA[mua.split()[0]]
+        mua_tmp = MUA[mua]
     output = '/dev/null'
     if os.path.exists(output):
         try:
-            returnvalue = subprocess.call(MUAVERSION[mua], stdout=open(output, 'w'), stderr=subprocess.STDOUT, shell=True)
+            returnvalue = subprocess.call(MUAVERSION[mua_tmp], stdout=open(output, 'w'), stderr=subprocess.STDOUT, shell=True)
         except IOError, OSError:
-            returnvalue = subprocess.call(MUAVERSION[mua], shell=True)
+            returnvalue = subprocess.call(MUAVERSION[mua_tmp], shell=True)
     else:
-        returnvalue = subprocess.call(MUAVERSION[mua], shell=True)
+        returnvalue = subprocess.call(MUAVERSION[mua_tmp], shell=True)
     # 127 is the shell standard return value to indicate a 'command not found' result
     if returnvalue == 127:
         return False
